(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define('@nonoll/code-snippet/browser', ['exports'], factory) :
    (global = global || self, factory((global.nonoll = global.nonoll || {}, global.nonoll['code-snippet'] = global.nonoll['code-snippet'] || {}, global.nonoll['code-snippet'].browser = {})));
}(this, (function (exports) { 'use strict';

    /**
     * browser - AOS 유무 반환
     * @memberof module:browser
     * @function
     * @return {Boolean}
     * @example
    import { isAOS } from '@nonoll/code-snippet/browser';
    console.log(isAOS()); // true or false
     */
    var isAOS = function () {
        return /Android/.test(window.navigator.userAgent);
    };

    /**
     * browser - IOS 유무 반환
     * @memberof module:browser
     * @function
     * @return {Boolean}
     * @example
    import { isIOS } from '@nonoll/code-snippet/browser';
    console.log(isIOS()); // true or false
     */
    var isIOS = function () {
        return /iPhone|iPad/.test(window.navigator.userAgent);
    };

    /**
     * passive 옵션 지원 유무 반환
     * @memberof module:browser
     * @function
     * @return {Boolean}
     * @see https://github.com/WICG/EventListenerOptions/pull/30
     * @see https://github.com/cubiq/iscroll/blob/master/demos/demoUtils.js#L2-L12
     * @see https://developers.google.com/web/tools/lighthouse/audits/passive-event-listeners?hl=ko
     * @example
    import { isSupportPassive } from '@nonoll/code-snippet/browser';
    console.log(isSupportPassive()); // true or false
     */
    /* istanbul ignore next */
    var isSupportPassive = function () {
        var supportPassiveOption = false;
        try {
            var options = Object.defineProperty({}, 'passive', { get: function () { return supportPassiveOption = true; } });
            addEventListener('test_passive_option', null, options);
        }
        catch (e) { }
        return supportPassiveOption;
    };
    /**
     * 실행된 browser 에서 지원하는 passive 옵션 값 반환
     * @memberof module:browser
     * @function
     * @return {(IPassive|Boolean)}
     * @see https://developers.google.com/web/tools/lighthouse/audits/passive-event-listeners?hl=ko
     * @example
    import { getPassiveOption } from '@nonoll/code-snippet/browser';
    console.log(getPassiveOption()); // IPassive or false
     */
    var getPassiveOption = function () { return isSupportPassive() ? { passive: true } : /* istanbul ignore next */ false; };

    /**
     * browser - vendorPrefix 반환
     * @memberof module:browser
     * @see https://davidwalsh.name/vendor-prefix
     * @function
     * @return {IVendorPrefix}
     * @example
    import { vendorPrefix } from '@nonoll/code-snippet/browser';
    console.log(vendorPrefix()); // {dom: "Webkit", lowercase: "webkit", css: "-webkit-", js: "Webkit"}
     */
    var vendorPrefix = function () {
        var styles = window.getComputedStyle(window.document.documentElement, '');
        // tslint:disable-next-line: max-line-length
        var pre = (Array.from(styles).join('').match(/-(moz|webkit|ms)-/) || /* istanbul ignore next */ (styles.OLink === '' && ['', 'o']))[1];
        var dom = ('Webkit|Moz|MS|O').match(new RegExp("(" + pre + ")", 'i'))[1];
        return {
            dom: dom,
            lowercase: pre,
            css: "-" + pre + "-",
            js: pre[0].toUpperCase() + pre.substr(1)
        };
    };

    exports.getPassiveOption = getPassiveOption;
    exports.isAOS = isAOS;
    exports.isIOS = isIOS;
    exports.isSupportPassive = isSupportPassive;
    exports.vendorPrefix = vendorPrefix;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=nonoll-code-snippet-browser.umd.js.map
